Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(134)

Unified Diff: cc/resources/resource_provider.cc

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/resources/resource_provider.h ('k') | cc/resources/resource_provider_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/resources/resource_provider.cc
diff --git a/cc/resources/resource_provider.cc b/cc/resources/resource_provider.cc
index 5782ede4e466170f21622ee95b52f921bf1c6118..b189fcb62cf76411b4a3c9639d0eda91eb115980 100644
--- a/cc/resources/resource_provider.cc
+++ b/cc/resources/resource_provider.cc
@@ -398,7 +398,7 @@ ResourceProvider::ResourceProvider(
shared_bitmap_manager_(shared_bitmap_manager),
gpu_memory_buffer_manager_(gpu_memory_buffer_manager),
blocking_main_thread_task_runner_(blocking_main_thread_task_runner),
- lost_output_surface_(false),
+ lost_context_provider_(false),
highp_threshold_min_(highp_threshold_min),
next_id_(1),
next_child_(1),
@@ -720,9 +720,9 @@ void ResourceProvider::DeleteResourceInternal(ResourceMap::iterator it,
// Exported resources are lost on shutdown.
bool exported_resource_lost =
style == FOR_SHUTDOWN && resource->exported_count > 0;
// GPU resources are lost when output surface is lost.
bool gpu_resource_lost =
- IsGpuResourceType(resource->type) && lost_output_surface_;
+ IsGpuResourceType(resource->type) && lost_context_provider_;
bool lost_resource =
resource->lost || exported_resource_lost || gpu_resource_lost;
@@ -1687,7 +1687,7 @@ void ResourceProvider::DeleteAndReturnUnusedResourcesToChild(
DCHECK(child_info->child_to_parent_map.count(child_id));
bool is_lost = resource.lost ||
- (IsGpuResourceType(resource.type) && lost_output_surface_);
+ (IsGpuResourceType(resource.type) && lost_context_provider_);
if (resource.exported_count > 0 || resource.lock_for_read_count > 0) {
if (style != FOR_SHUTDOWN) {
// Defer this resource deletion.
@@ -720,9 +720,9 @@ void ResourceProvider::DeleteResourceInternal(ResourceMap::iterator it,
bool exported_resource_lost =
style == FOR_SHUTDOWN && resource->exported_count > 0;
- // GPU resources are lost when output surface is lost.
+ // GPU resources are lost when context is lost.
bool gpu_resource_lost =
« no previous file with comments | « cc/resources/resource_provider.h ('k') | cc/resources/resource_provider_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698